==> order-center-infrastructure-2.0.9-CLOUD-TEST-20220402.094724-42-sources.jar: com/tydic/dyc/oc/repository/po/UocOrderAgreementPo.java <==
package com.tydic.dyc.oc.repository.po;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocOrderAgreementPo
 * 说明:协议信息表
 * 时间:2022-04-02 14:52
 * 作者:罗有
 **/
@Data
public class UocOrderAgreementPo implements Serializable {
	private static final long serialVersionUID = 5280411851318508708L;

	private Long id;

	@DocField(value = "协议Id")
	private String agreementId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "协议模式 1：平台协议 2：单位协议")
	private Integer agreementCode;

	@DocField(value = "协议版本号")
	private String agreementVersion;

	@DocField(value = "平台协议编号")
	private String plaAgreementCode;

	@DocField(value = "企业协议编号")
	private String entAgreementCode;

	@DocField(value = "协议名称")
	private String agreementName;

	@DocField(value = "是否存在加价项 0：否 1：是")
	private Integer isAddPrice;

	@DocField(value = "配置状态 0：已分配 1：待分配 ")
	private Integer assignStatus;

	@DocField(value = "是否公式调价 0：否 1：是")
	private Integer isAdjustPriceFormula;

	@DocField(value = "是否手动修改采购单价 0:否 1：是")
	private Integer isModifyBuyPrice;

	@DocField(value = "调价公式名称")
	private String adjustPriceFormulaName;

	@DocField(value = "调价公式值")
	private String adjustPriceFormulaValue;

	@DocField(value = "税率 ")
	private Integer taxRate;

	@DocField(value = "币种，0：人民币 默认0")
	private Integer currency;

	@DocField(value = "协议生效日期")
	private Date effDate;

	@DocField(value = "协议生效日期 开始")
	private Date effDateStart;

	@DocField(value = "协议生效日期 结束")
	private Date effDateEnd;

	@DocField(value = "协议失效日期")
	private Date expDate;

	@DocField(value = "协议失效日期 开始")
	private Date expDateStart;

	@DocField(value = "协议失效日期 结束")
	private Date expDateEnd;

	@DocField(value = "预付款(对项目单位)")
	private BigDecimal prePayEnt;

	@DocField(value = "投料款(对项目单位)")
	private BigDecimal matPayEnt;

	@DocField(value = "进度款(对项目单位)")
	private BigDecimal proPayEnt;

	@DocField(value = "到货验收款(对项目单位)")
	private BigDecimal verPayEnt;

	@DocField(value = "试运行验收款(对项目单位)")
	private BigDecimal pilPayEnt;

	@DocField(value = "质保金(对项目单位)")
	private BigDecimal quaPayEnt;

	@DocField(value = "投料款(对供应商)")
	private BigDecimal matPaySup;

	@DocField(value = "进度款(对供应商)")
	private BigDecimal proPaySup;

	@DocField(value = "到货验收款(对供应商)")
	private BigDecimal verPaySup;

	@DocField(value = "试运行验收款(对供应商)")
	private BigDecimal pilPaySup;

	@DocField(value = "质保金(对供应商)")
	private BigDecimal quaPaySup;

	@DocField(value = "预付款(对供应商)")
	private BigDecimal prePaySup;

	@DocField(value = "供货周期 单位天")
	private Integer supplyCycle;

	@DocField(value = "质保期(月)")
	private Integer warantty;

	@DocField(value = "是否配送 0:否,1是 默认值：是 ")
	private Integer isDispatch;

	@DocField(value = "成交服务费比率 选项：0, 2.5, 5.0")
	private BigDecimal serviceRate;

	@DocField(value = "结算单位id")
	private Long unitAccountId;

	@DocField(value = "结算单位名称")
	private String unitAccountName;

	@DocField(value = "铺货单位id")
	private Long supplierId;

	@DocField(value = "铺货单位名称")
	private String supplierName;

	@DocField(value = "供货商id")
	private Long vendorId;

	@DocField(value = "供货商名称")
	private String vendorName;

	@DocField(value = "供货商联系人")
	private String vendorContact;

	@DocField(value = "供货商联系电话")
	private String vendorPhone;

	@DocField(value = "铺货部门id")
	private Long vendorDepartmentId;

	@DocField(value = "铺货部门名称")
	private String vendorDepartmentName;

	@DocField(value = "协议创建日期")
	private Date createTime;

	@DocField(value = "协议创建日期 开始")
	private Date createTimeStart;

	@DocField(value = "协议创建日期 结束")
	private Date createTimeEnd;

	@DocField(value = "调价机制：0：无，1：事前调价，2：事中调价 默认值：0")
	private Integer adjustPrice;

	@DocField(value = "铺货联系人")
	private String vendorContactPerson;

	@DocField(value = "铺货联系方式")
	private String vendorContactWay;

	@DocField(value = "铺货联系地址")
	private String vendorContactAddress;

	@DocField(value = "协议经办人")
	private Long producerId;

	@DocField(value = "协议经办人名字")
	private String producerName;

	@DocField(value = "协议经办人电话")
	private String producerPhone;

	@DocField(value = "交易模式 1：贸易模式 2：搓合模式")
	private Integer tradeMode;

	@DocField(value = "应用范围类型：0：全部:1：省份、2：行业:3：分子公司:4：项目单位 默认值：无")
	private Integer scopeType;

	@DocField(value = "排序")
	private String orderBy;

}

==> order-center-infrastructure-3.1.0-CLOUD-TEST-20230911.061538-104-sources.jar: com/tydic/dyc/oc/repository/po/UocOrderAgreementPo.java <==
package com.tydic.dyc.oc.repository.po;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocOrderAgreementPo
 * 说明:协议信息表
 * 时间:2022-04-02 14:52
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocOrderAgreementPo implements Serializable {
	private static final long serialVersionUID = 5280411851318508708L;

	private Long id;

	//协议Id")
	private String agreementId;

	//订单id")
	private Long orderId;

	//协议模式 1：平台协议 2：单位协议")
	private Integer agreementCode;

	//协议版本号")
	private String agreementVersion;

	//平台协议编号")
	private String plaAgreementCode;

	//企业协议编号")
	private String entAgreementCode;

	//协议名称")
	private String agreementName;

	//是否存在加价项 0：否 1：是")
	private Integer isAddPrice;

	//配置状态 0：已分配 1：待分配 ")
	private Integer assignStatus;

	//是否公式调价 0：否 1：是")
	private Integer isAdjustPriceFormula;

	//是否手动修改采购单价 0:否 1：是")
	private Integer isModifyBuyPrice;

	//调价公式名称")
	private String adjustPriceFormulaName;

	//调价公式值")
	private String adjustPriceFormulaValue;

	//税率 ")
	private String taxRate;

	//币种，0：人民币 默认0")
	private Integer currency;

	//协议生效日期")
	private Date effDate;

	//协议生效日期 开始")
	private Date effDateStart;

	//协议生效日期 结束")
	private Date effDateEnd;

	//协议失效日期")
	private Date expDate;

	//协议失效日期 开始")
	private Date expDateStart;

	//协议失效日期 结束")
	private Date expDateEnd;

	//预付款(对项目单位)")
	private BigDecimal prePayEnt;

	//投料款(对项目单位)")
	private BigDecimal matPayEnt;

	//进度款(对项目单位)")
	private BigDecimal proPayEnt;

	//到货验收款(对项目单位)")
	private BigDecimal verPayEnt;

	//试运行验收款(对项目单位)")
	private BigDecimal pilPayEnt;

	//质保金(对项目单位)")
	private BigDecimal quaPayEnt;

	//投料款(对供应商)")
	private BigDecimal matPaySup;

	//进度款(对供应商)")
	private BigDecimal proPaySup;

	//到货验收款(对供应商)")
	private BigDecimal verPaySup;

	//试运行验收款(对供应商)")
	private BigDecimal pilPaySup;

	//质保金(对供应商)")
	private BigDecimal quaPaySup;

	//预付款(对供应商)")
	private BigDecimal prePaySup;

	//供货周期 单位天")
	private Integer supplyCycle;

	//质保期(月)")
	private Integer warantty;

	//是否配送 0:否,1是 默认值：是 ")
	private Integer isDispatch;

	//成交服务费比率 选项：0, 2.5, 5.0")
	private BigDecimal serviceRate;

	//结算单位id")
	private Long unitAccountId;

	//结算单位名称")
	private String unitAccountName;

	//铺货单位id")
	private Long supplierId;

	//铺货单位名称")
	private String supplierName;

	//供货商id")
	private Long vendorId;

	//供货商名称")
	private String vendorName;

	//供货商联系人")
	private String vendorContact;

	//供货商联系电话")
	private String vendorPhone;

	//铺货部门id")
	private Long vendorDepartmentId;

	//铺货部门名称")
	private String vendorDepartmentName;

	//协议创建日期")
	private Date createTime;

	//协议创建日期 开始")
	private Date createTimeStart;

	//协议创建日期 结束")
	private Date createTimeEnd;

	//调价，2事中")
	private Integer adjustPrice;

	//铺货联系人")
	private String vendorContactPerson;

	//铺货联系方式")
	private String vendorContactWay;

	//铺货联系地址")
	private String vendorContactAddress;

	//协议经办人")
	private Long producerId;

	//协议经办人名字")
	private String producerName;

	//协议经办人电话")
	private String producerPhone;

	//交易模式 1：贸易模式 2：搓合模式")
	private Integer tradeMode;

	//应用范围类型：0：全部:1：省份、2：行业:3：分子公司:4：项目单位 默认值：无")
	private Integer scopeType;

	//排序")
	private String orderBy;

	//删除标识删除标志1已删除")
	private Integer delTag;
	 //@DocField(value = "归档表后缀")
	private String dataAchiveTabSuffix;
    /**
     *合同号
     */
    private String relCode;
    /**
     *合同名称
     */
    private String relName;
    
    //项目类型（1:物资 2:工程 3:服务）
    private Integer agreementVariety;
    //项目类型（1:物资 2:工程 3:服务）
//    private String agreementVarietyStr;
    //合同来源类别6:原始合同 7:续约合同 8:补充合同
    private Integer agrSrc;
//    private String agrSrcStr;
}
